#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Fri Sep 11 13:02:36 2020

@author: safir
"""

import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="classic_FindS", 
    version="2.0.0",
    author="Safir Motiwala",
    author_email="safirmotiwala@gmail.com",
    description="Find-S algorithm is a Machine Learning Algorithm that finds the most specific hypothesis that fits all the positive examples.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/safir72347/ML-FindS-PyPi",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.0',
)


#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Wed Sep  9 19:30:47 2020

@author: safir
"""

import numpy as np

class FindS:
    def __init__(self):
        self.Xtrain = ""
        self.ytrain = ""
        self.Xtest = ""
        self.ytest = ""
        self.specific_hypothesis = []
    
    def fit(self, X, y):
        count = 0
        self.Xtrain, self.ytrain = X, y
        for i, val in enumerate(y):
            if val==1:
                S_hypothesis = list(X[0].copy())
                print("Initial : ", S_hypothesis)
                break
        for i, val in enumerate(X):
            if y[i]==1:
                count+=1
                for x in range(len(S_hypothesis)):
                    if val[x] == S_hypothesis[x]:
                        pass
                    else:
                        S_hypothesis[x] = '?'
        print("Total Positive Records : ", count)
        self.specific_hypothesis = S_hypothesis
        return S_hypothesis
    
    def predict(self, X):
        y = np.array([0 for i in range(len(X))])
        self.Xtest = X
        for i, val in enumerate(X):
            val = list(val)
            check = 0
            for x in range(len(val)):
                if val[x] == self.specific_hypothesis[x]:
                    check+=1
                else:
                    pass
            if check>0:
                y[i] = 1
            else:
                y[i] = 0
        self.ytest = y
        return y